@@ -35,8 +35,6 @@
 // If you do not wish that, delete this exception notice.
 //
 
-#pragma warning(disable: 4996)
-
 #ifndef	CCXX_BAYONNE_H_
 #define	CCXX_BAYONNE_H_
 
@@ -952,6 +950,8 @@ public:
 	 */
 	BayonneTranslator(const char *iso);
 
+	virtual ~BayonneTranslator();
+
 	/**
 	 * Find a translator for a given name/location.
 	 *
@@ -1454,7 +1454,7 @@ public:
 	 * @param max count of elements available.
 	 * @return number of drivers.
 	 */
-	static unsigned BayonneDriver::list(char **items, unsigned max);
+	static unsigned list(char **items, unsigned max);
 
 	/**
 	 * Start all loaded drivers.
