@@ -295,7 +295,7 @@ void Driver::setAuthentication(Registry *reg)
 		*p = 0;
 
 	eXosip_lock();
-	int rtn = eXosip_add_authentication_info(uname, uname, reg->secret, NULL, reg->realm);
+	eXosip_add_authentication_info(uname, uname, reg->secret, NULL, reg->realm);
 	eXosip_unlock();
 }
 		
@@ -377,7 +377,7 @@ void Driver::startDriver(void)
 	case mulawAudio:
 		if(!data_negotiate)
 			setValue("payload", "0");
-		snprintf(cbuf, sizeof(cbuf), "%d PCMU/%d", 
+		snprintf(cbuf, sizeof(cbuf), "%d PCMU/%ld", 
 			data_negotiate, info.rate);
 		break;
 	case alawAudio:
@@ -386,15 +386,15 @@ void Driver::startDriver(void)
 			data_negotiate = 8;
 			setValue("payload", "8");
 		}
-		snprintf(cbuf, sizeof(cbuf), "%d PCMA/%d",
+		snprintf(cbuf, sizeof(cbuf), "%d PCMA/%ld",
 			data_negotiate, info.rate);
 		break;
 	case pcm16Mono:
-		snprintf(cbuf, sizeof(cbuf), "%d L16/%d",
+		snprintf(cbuf, sizeof(cbuf), "%d L16/%ld",
 			data_negotiate, info.rate);
 		break;
 	case pcm16Stereo:
-		snprintf(cbuf, sizeof(cbuf), "%d L16_2CH/%d",
+		snprintf(cbuf, sizeof(cbuf), "%d L16_2CH/%ld",
 			data_negotiate, info.rate);
 		break;
 	case speexVoice:
@@ -403,7 +403,7 @@ void Driver::startDriver(void)
 			data_negotiate = 97;
 			setValue("payload", "97");
 		}
-		snprintf(cbuf, sizeof(cbuf), "%d SPEEX/%d",
+		snprintf(cbuf, sizeof(cbuf), "%d SPEEX/%ld",
 			data_negotiate, info.rate);
 		break;
 	case gsmVoice:
@@ -412,7 +412,7 @@ void Driver::startDriver(void)
 			data_negotiate = 3;
 			setValue("payload", "3");
 		}
-		snprintf(cbuf, sizeof(cbuf), "%d GSM/%d",
+		snprintf(cbuf, sizeof(cbuf), "%d GSM/%ld",
 			data_negotiate, info.rate);
 		break;
 	default:
@@ -813,8 +813,8 @@ void Driver::run(void)
 	osip_content_type_t *ct;
 	sdp_media_t *remote_media, *local_media, *audio_media;
 	char *tmp, *audio_payload, *adp;
-	const char *data_rtpmap;
-	int pos, mpos, rtn, apos;
+	const char *data_rtpmap = NULL;
+	int pos, mpos, rtn;
 	sdp_attribute_t *attr;
 	char *sdp;
 	bool reg_inband;
@@ -1484,6 +1484,8 @@ sip415:
 					session->data_payload = 97;
 					data_rtpmap = "L16/8000/1";
 				}
+			default:
+				break;
 			}
 			audio_payload = NULL;
 			while(!osip_list_eol(remote_sdp->m_medias, mpos))
@@ -1649,6 +1651,7 @@ clear:
 				osip_free(local_uri);
 
 			eXosip_unlock();
+		default:
 			break;
 		}			
 		eXosip_event_free(sevent);
