@@ -45,6 +45,23 @@ namespace sipdriver {
 using namespace ost;
 using namespace std;
 
+struct dtmf2833
+{
+#if __BYTE_ORDER == __BIG_ENDIAN
+        unsigned event : 8;
+        unsigned char ebit : 1;
+        unsigned char rbit : 1;
+        unsigned vol : 6;
+        uint32 duration : 16;
+#else
+        unsigned event : 8;
+        unsigned vol : 6;
+        unsigned char rbit : 1;
+        unsigned char ebit : 1;
+        uint32 duration : 16;
+#endif
+};
+
 class Session;
 
 class Registry : public ScriptRegistry
@@ -62,6 +79,8 @@ public:
 	const char *type;
 	const char *realm;
 	const char *dtmf;
+	const char *encoding;
+	timeout_t framing;
 	int regid;
 	bool active;
 
@@ -78,14 +97,13 @@ protected:
 	InetAddress sip_addr, rtp_addr;
 	tpport_t rtp_port, sip_port;
 	uint8 dtmf_negotiate, data_negotiate;
+	bool info_negotiate;
 	Info info;
 	bool registry;
 	bool exiting;
 	bool dtmf_inband;
 	bool data_filler;
 	Level silence;
-	Linear silent_frame;
-	Encoded silent_encoded;
 	unsigned jitter;
 	timeout_t accept_timer;
 	timeout_t audio_timer;
@@ -122,13 +140,19 @@ private:
 	friend class Session;
 
 protected:
+	Encoded pbuffer;
+	Encoded buffer;
+	Linear lbuffer;
+	Linear silent_frame;
+	Encoded silent_encoded;
 	DTMFDetect *dtmf;
         Session *session;
         size_t rtpBufferSize;
         bool dropInbound;
 	bool ending;
-	unsigned long fcount, jitter, jsend;
-	
+	unsigned long fcount, jitter, jsend, dtmfcount;
+
+	struct dtmf2833 dtmfpacket;	
 	unsigned lastevt;
 	unsigned tonecount;
 	event_t stopid;
@@ -146,15 +170,18 @@ public:
 
         void start(void);
 
+	void put2833(struct dtmf2833 *data);
         ssize_t putBuffer(Encoded data, size_t len);
         ssize_t getBuffer(Encoded data, size_t len);
 
         void run(void);
-	void peerAudio(Encoded encoded);
+	void peerAudio(Encoded encoded, bool linear);
+	void postAudio(Encoded encoded);
 
         void setSource(AudioBase *get, timeout_t max = 0);
         void setSink(AudioBase *put, timeout_t max = 0);
 	void setTone(AudioTone *tone, timeout_t max = 0);
+	void set2833(struct dtmf2833 *data, timeout_t duration);
 
 	inline bool isEnding(void)
 		{return ending;};
@@ -171,22 +198,21 @@ protected:
 	friend class Driver;
 	friend class RTPStream;
 
+	Info info;
 	AudioCodec *codec;
 	InetHostAddress local_address, remote_address;
 	tpport_t remote_port;
 	RTPStream *rtp;
 	bool update_pos;
-	Encoded buffer;
-	Linear lbuffer;
 	Linear peer_buffer;
 	AudioCodec *peer_codec;
 	uint8 dtmf_payload, data_payload;
+	bool dtmf_sipinfo;
 	volatile bool dtmf_inband;
 
 	int cid, did;
 
 	bool peerAudio(Encoded encoded);
-	void postAudio(Encoded encoded);
 
 	void sendDTMFInfo(char digit, unsigned timeout = 160);
 
@@ -196,6 +222,9 @@ public:
 	Session(timeslot_t ts);
 	~Session();
 
+	timeout_t audioFraming(void);
+	const char *audioEncoding(void);
+	const char *audioExtension(void);
 	const char *checkAudio(bool live);
 
 	// core timer virtuals all port session objects need to define
@@ -211,6 +240,8 @@ public:
 
 	void clrAudio(void);
 
+	bool enterJoin(Event *event);
+
 	bool enterSeize(Event *event);
 
 	bool enterRunning(Event *event);
@@ -241,6 +272,9 @@ public:
 
 	inline InetHostAddress getRemoteAddress(void)
 		{return remote_address;};
+
+	void setEncoding(const char *encoding, timeout_t framing);
+
 };
 
 }
