@@ -237,8 +237,9 @@ bool Session::enterJoin(Event *event)
 		if(audio.tone)
 			rtp->setTone(audio.tone);
 		return true;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool Session::enterSeize(Event *event)
@@ -248,13 +249,12 @@ bool Session::enterSeize(Event *event)
 	const char *cp, *to, *from = NULL;
 	char *sp = NULL;
 	osip_message_t *invite = NULL;
-	Name *scr = ScriptInterp::getName();
 	Registry *reg = NULL;
 	ScriptImage *img = getImage();
 	char rbuf[16];
 	char cbuf[65];
 	char sdp[512];
-	const char *rtpmap;
+	const char *rtpmap = NULL;
 	const char *route;
         const char *lp = driver->getLast("localip");
 	BayonneSession *parent = Bayonne::getSid(var_pid);
@@ -405,6 +405,7 @@ failure:
 		case speexVoice:
 			data_payload = 97;
 			rtpmap = "a=rtpmap:97 SPEEX/8000/1";
+		default:
 			break;
 		}			
 		if(dtmf_payload)
@@ -472,9 +473,9 @@ failure:
 		return true;
 	case TIMER_EXPIRED:
 		offhook = false;
+	default:
 		return false;
 	}
-	return false;
 }
 
 bool Session::enterHangup(Event *event)
@@ -483,6 +484,8 @@ bool Session::enterHangup(Event *event)
 	{
 	case TIMER_EXPIRED:
 		sipHangup();
+	default:
+		break;
 	}
 
 	update_pos = false;
@@ -505,8 +508,9 @@ bool Session::enterRecord(Event *event)
 		}
 		rtp->setSink(&audio, state.audio.total);
 		return false;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool Session::enterPlay(Event *event)
@@ -533,8 +537,9 @@ bool Session::enterPlay(Event *event)
 		}
 		rtp->setSource(&audio);		
 		return false;
+	default:
+		return false;
 	}
-	return false;
 }
 
 bool Session::enterPickup(Event *event)
@@ -587,8 +592,9 @@ bool Session::enterXfer(Event *event)
 	case STOP_DISCONNECT:
 		setState(STATE_HANGUP);
 		return true;
+	default:
+		return false;
 	}	
-	return false;
 }
 
 void Session::clrAudio(void)
@@ -649,6 +655,7 @@ const char *Session::checkAudio(bool live)
 		if(!audio.extension)
 			audio.extension = ".gsm";
 		audio.libext = ".gsm";
+	default:
 		break;
 	}
 
