@@ -506,12 +506,10 @@ bool Runtime::command(char *cmd)
 	BayonneSession *s;
 	const char *cp;
 	bool rtn;
-	BayonneDriver *d;
 	const char *dial, *caller, *display;
 	char buf[65];
 	const char *args[65];
 	int argc = 0;
-	char *sp;
 
 	cmd = strtok_r(cmd, " \t\r\n", &tok);
 	if(!cmd || ispunct(*cmd) || !*cmd)
@@ -685,8 +683,7 @@ void Runtime::process(void)
 	{
 		for(;;)
 		{
-			fgets(buf, sizeof(buf), fp);
-			if(feof(fp))
+			if(!fgets(buf, sizeof(buf), fp) || feof(fp))
 				break;
 			cp = buf;
                 	while(isspace(*cp))
